summaryrefslogtreecommitdiffstats
path: root/kviewshell/pageView.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
commitec1fddcd0d6663ad273af85357f04abbc5689468 (patch)
tree6cb946ab8b4771868c6eee8d1aa5213d6ec246e2 /kviewshell/pageView.h
parentc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (diff)
downloadtdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.tar.gz
tdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.
Diffstat (limited to 'kviewshell/pageView.h')
-rw-r--r--kviewshell/pageView.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kviewshell/pageView.h b/kviewshell/pageView.h
index 14b6fab2..637a7e23 100644
--- a/kviewshell/pageView.h
+++ b/kviewshell/pageView.h
@@ -106,8 +106,8 @@ public slots:
/** Turn the scrollbars on/off. */
void slotShowScrollbars(bool);
- /** Set layout of the page widgets according to the current viewmode and zoomlevel.
- Set zoomChanged = true if the the layout needs updateing because the zoomlevel has changed. */
+ /** Set tqlayout of the page widgets according to the current viewmode and zoomlevel.
+ Set zoomChanged = true if the the tqlayout needs updateing because the zoomlevel has changed. */
void layoutPages(bool zoomChanged = false);
void slotEnableMoveTool(bool enable);